(v0.12.3)=
### 0.12.3 {small}`2025-10-16`

#### Miscellaneous changes

- Deprecate `AnnData.*_keys()` methods. {user}`flying-sheep` ({pr}`2102`)

#### Bug fixes

- Deprecate `__version__` and use standard {func}`~importlib.metadata.version` API {user}`flying-sheep` ({pr}`1318`)
- Allow writing of views of {class}`dask.array.Array` {user}`ilan-gold` ({pr}`2084`)
- Enable writing of views of {class}`~anndata.AnnData` in backed mode {user}`ilan-gold` ({pr}`2092`)
- Reallow writing of keys in `h5ad` files with forward slashes instead of erroring.  Now a warning will be raised that the behavior will be disallowed in the future.  To enable the new behavior, use {attr}`anndata.settings.disallow_forward_slash_in_h5ad`. {user}`ilan-gold` ({pr}`2097`)
- Respect off-axis merge options in {func}`anndata.experimental.concat_on_disk` {user}`ilan-gold` ({pr}`2122`)
